<?php 

/** 

EasyPhpAlbum Lite Version 2.3.3 - PHP5
Copyright (c) 2008-2014 JF Nutbroek <jfnutbroek@gmail.com>

Permission to use, copy, modify, and/or distribute this software for any
purpose without fee is hereby granted, provided that the above
copyright notice and this permission notice appear in all copies.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.

**** INSTRUCTIONS ****

Upload this file together with photos to a photoalbum directory on your webserver. That's all!

If you would like to organize your photos you can create as many directories and sub directories 
in your photoalbum directory as you need. It is not necessary to copy the EasyPhpAlbum Lite file
to the other directories, you only need it once in the top directory!

**** WHAT DOES IT DO? ****

- Your albums will be indexed and organized in a menu for easy navigation
- Thumbnails (smaller versions of the photos) will be saved when possible (upon first viewing request)
- A visitor can select an album, browse through the thumbnails and click a thumbnail to view the larger photo
- A visitor can browse forward and backward through the album or start a simple slideshow
- A visitor can change the amount of thumbnails being displayed to best fit the screen

**** Can I 'tweak' it? ****

- Yes, some simple tweaks are the settings mentioned below
- Once your album is online enable the tweak '$menu_cache' for faster page loads
- For further tweaking you can edit the code

Enjoy!

*/

// Some tweaks

$menu_cache     = false;                         // Enable/disable caching of the menu (improves speed!, clear cache with 'exit' menu option)
$browsing       = true;                          // Allow forward and backward browsing
$thumbnailgrid  = '4x4';                         // The standard dimensions of the initial thumbnail grid, columns x rows
$changegrid     = true;                          // Allow the thumbnail grid to be expanded or contracted
$slideshow      = true;                          // Allow the slideshow option
$slideshowdelay = 3000;                          // Delay for slideshow in milliseconds
$show_name      = true;                          // Show filename below photo
$thumbwidth     = 140;                           // The width (or height) of the thumbnail in px - change it, then: delete old thumbnails, clear browser cache, clear session
$exitpage       = 'http://www.mywebmymail.com';  // 'Exit' will take the visitor to the page he came from, or to the URL mentioned here
$scriptname     = 'index.php';                   // The filename of the script in case you want to change it
$roundcorners	= true;			 	 // Round the corners of the thumbnail

// EasyPhpAlbum Lite

session_start();

// Determine the exit URL for the exit menu option
if (!isset($_SESSION['exit'])) {
        $_SESSION['exit'] = $exitpage;
	if (isset($_SERVER['HTTP_REFERER']) && isset($_SERVER['HTTP_HOST']) && isset($_SERVER['PHP_SELF'])) {
                $thispage = strtolower('http://' . $_SERVER['HTTP_HOST'] . $_SERVER['PHP_SELF']);
                if (substr(strtolower($_SERVER['HTTP_REFERER']), 0, strlen($thispage)) != $thispage)
                        $_SESSION['exit'] = $_SERVER['HTTP_REFERER'];     
        }
}

// Verify if browser supports inline images
if (!isset($_SESSION['RFC2397'])) {
	$_SESSION['RFC2397'] = get_rfc2397();
}

// Action when 'exit' is selected from the menu
if (isset($_REQUEST['exit'])) {
        $url = $_SESSION['exit'];
        session_unset();
	session_destroy();
        header("Location: "  .  $url); 
	exit;
}

// A new album is currently being viewed -> reset the image cache
if (isset($_REQUEST['album'])) {
        $_SESSION['album'] = intval($_REQUEST['album']);
	unset($_SESSION['images']);
}

// Determine which page is being viewed
if (isset($_REQUEST['page'])) {$page = intval($_REQUEST['page']);} else {$page = 1;}

// Set width of thumbnail content section and initial display grid
if (!isset($_SESSION['columns'])) {
	$grid = explode('x', $thumbnailgrid);
	$_SESSION['columns'] = $grid[0];
}
if (!isset($_SESSION['rows'])) {
	$grid = explode('x', $thumbnailgrid);
	$_SESSION['rows'] = $grid[1];
}
if (!isset($_SESSION['width'])) {
	$_SESSION['width'] = 60 + $_SESSION['columns'] * ($thumbwidth + 30);
}

// Change the amount of columns (images next to each other)
if (isset($_REQUEST['columns']) && $changegrid) {
        $_SESSION['columns'] = max(1, intval($_REQUEST['columns']));
	if ($_SESSION['columns'] <= 4) {
		$_SESSION['width'] = 60 + $_SESSION['columns'] * ($thumbwidth + 30);
	} else {
		$_SESSION['width'] = 60 + $_SESSION['columns'] * ($thumbwidth + 30);
	}
}

// Change the amount of rows (images under each other)
if (isset($_REQUEST['rows']) && $changegrid) {
        $_SESSION['rows'] = max(1, intval($_REQUEST['rows']));
}

// A class to generate rounded thumbnails (see also the full version of EasyPhpThumbnail for custom modifications)
class easyphpthumbnail {
		
	public  $Thumbsize;			
	public  $Chmodlevel;	
	public  $Thumblocation;
	public  $Clipcorner;
	public  $Backgroundcolor;
	public  $Quality;
	private $image;			
	private $im;			
	private $thumb;			
	private $size;
	private $thumbx;				
	private $thumby;
	private $memsize;

	public function __construct() {
	
		$this -> Thumbsize           =  140;
		$this -> Chmodlevel          =  '0777';
		$this -> Thumblocation       =  '';
		$this -> Clipcorner          =  array(2, 15, 0, 1, 1, 1, 1);
		$this -> Backgroundcolor     =  '#FFFFFF';
		$this -> Quality             =  '90';
		$this -> memsize             =  $this -> return_bytes(ini_get('memory_limit')) * 0.55 - ($this -> Thumbsize * $this -> Thumbsize * 4);
		
	}
	
	public function __destruct() {
        
		if(is_resource($this -> im)) imagedestroy($this -> im);
		if(is_resource($this -> thumb)) imagedestroy($this -> thumb);
        
	}
	
	public function Createthumb($filename = "unknown") {

		if (is_array($filename)) {
			foreach ($filename as $name) {
				$this -> image = $name;
				$this -> thumbmaker();
			}
		} else {
			$this -> image = $filename;
			$this -> thumbmaker();
		}
                
	}

	private function thumbmaker() {

		if ($this -> loadimage()) {
			if ($this -> Clipcorner[0] == 2) {$this -> clipcornersround();}
			$this -> createemptythumbnail();
			imagecopyresampled($this -> thumb,$this -> im, 0, 0, 0, 0, $this -> thumbx,$this -> thumby,imagesx($this -> im),imagesy($this -> im));
			$this -> savethumb();
		}
                
	}
        
	private function loadimage() {
	
		if (file_exists($this -> image)) {
			$this -> size = getimagesize($this -> image);
			if ($this -> memsize>0) {
					if (($this -> size[0]*$this -> size[1]*4)>$this -> memsize) {return false;}
			}
			switch($this -> size[2]) {
				case 1:
					if (imagetypes() & IMG_GIF) {$this -> im = imagecreatefromgif($this -> image);} 
					break;
				case 2:
					if (imagetypes() & IMG_JPG) {$this -> im = imagecreatefromjpeg($this -> image);} 
					break;
				case 3:
					if (imagetypes() & IMG_PNG) {$this -> im = imagecreatefrompng($this -> image);} 
					break;
				default:
					return false;
			}
			if (!$this -> im) {return false;} else {return true;}
		} else {
			return false;	
		}  
      
	}

	private function createemptythumbnail() {
        
		if ($this -> size[0]>$this -> size[1])
			$this -> thumb = imagecreatetruecolor($this -> Thumbsize, ceil($this -> size[1]/($this -> size[0]/$this -> Thumbsize)));
		else
			$this -> thumb = imagecreatetruecolor(ceil($this -> size[0]/($this -> size[1]/$this -> Thumbsize)), $this -> Thumbsize);
		$this -> thumbx = imagesx($this -> thumb);
		$this -> thumby = imagesy($this -> thumb);
		imagefilledrectangle($this -> thumb, 0, 0, $this -> thumbx,$this -> thumby, imagecolorallocate($this -> thumb,hexdec(substr($this -> Backgroundcolor, 1, 2)),hexdec(substr($this -> Backgroundcolor, 3, 2)),hexdec(substr($this -> Backgroundcolor, 5, 2))));
        
	}

	private function clipcornersround() {
        
		$clipsize = floor($this -> size[0]*($this -> Clipcorner[1]/100));
		$clip_degrees = 90/max($clipsize, 1);
		$points_tl = array(0, 0);
		$points_br = array($this -> size[0], $this -> size[1]);
		$points_tr = array($this -> size[0], 0);
		$points_bl = array(0, $this -> size[1]);
		$bgcolor = imagecolorallocate($this -> im,hexdec(substr($this -> Backgroundcolor, 1, 2)),hexdec(substr($this -> Backgroundcolor, 3, 2)),hexdec(substr($this -> Backgroundcolor, 5, 2)));
		for ($i = 0;$i < $clipsize;$i++) {
			$x = $clipsize * cos(deg2rad($i * $clip_degrees));
			$y = $clipsize * sin(deg2rad($i * $clip_degrees));
			array_push($points_tl, $clipsize - $x);
			array_push($points_tl, $clipsize - $y);
			array_push($points_tr, $this -> size[0] - $clipsize + $x);
			array_push($points_tr, $clipsize-$y);
			array_push($points_br, $this -> size[0] - $clipsize + $x);
			array_push($points_br, $this -> size[1] - $clipsize + $y);
			array_push($points_bl, $clipsize-$x);
			array_push($points_bl, $this -> size[1] - $clipsize + $y);
		}
		array_push($points_tl, $clipsize,0);
		array_push($points_br, $this -> size[0] - $clipsize, $this -> size[1]);
		array_push($points_tr, $this -> size[0] - $clipsize, 0);
		array_push($points_bl, $clipsize, $this -> size[1]);
		imagefilledpolygon($this -> im, $points_tl, count($points_tl) / 2, $bgcolor);
		imagefilledpolygon($this -> im, $points_bl, count($points_bl) / 2, $bgcolor);          
		imagefilledpolygon($this -> im, $points_tr, count($points_tr) / 2, $bgcolor);          
		imagefilledpolygon($this -> im, $points_br, count($points_br) / 2, $bgcolor);
		imagerectangle($this -> im, 0, 0, $this -> size[0] - 1, $this -> size[1] - 1, $bgcolor);

	}
        
	private function savethumb() {
        
		$this -> image = substr($this -> image, 0, strrpos($this -> image, '.')) . ".jpg";
		if (!file_exists($this -> Thumblocation)) {
			mkdir($this -> Thumblocation);
			chmod($this -> Thumblocation, octdec($this -> Chmodlevel));
		}
		imagejpeg($this -> thumb, $this -> Thumblocation . basename($this -> image), $this -> Quality);
		if ($this -> Chmodlevel != '') {chmod($this -> Thumblocation . basename($this -> image), octdec($this -> Chmodlevel));}
		imagedestroy($this -> im);
		imagedestroy($this -> thumb);
                
	}
	
	private function return_bytes($size_str) {
	
		switch (substr ($size_str, -1)) {
			case 'M': case 'm': return (int)$size_str * 1048576;
			case 'K': case 'k': return (int)$size_str * 1024;
			case 'G': case 'g': return (int)$size_str * 1073741824;
			default: return intval($size_str);
		}
		
	}
  
}

// The page head containing CSS code
?>

<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd"><html xmlns="http://www.w3.org/1999/xhtml" lang="en" xml:lang="en">
<head><title>EasyPhpAlbum Lite &copy; 2008-2014 www.mywebmymail.com</title>
<meta http-equiv="Content-Type" content="text/html;charset=utf-8" />
<style type="text/css">  
body {
    background-color   : #CDE;
    height             : 100%; 
    max-height         : 100%; 
    font-family        : Verdana, Helvetica, Arial, sans-serif;
    font-size          : 0.75em;
    color              : #666; 
}
<?
if (!isset($_REQUEST['slideshow'])) {
	echo "#leftmenu {\n";
    	echo "    position           : absolute;\n";
    	echo "    width              : 180px;\n";
    	echo "    height             : auto;\n";
    	echo "    overflow           : auto;\n";
    	echo "    margin             : 15px;\n";
    	echo "    background-color   : #FFF;\n";
    	echo "    padding-top        : 15px;\n";
	echo "}\n";
}
echo "#content {\n";
echo "    position           : absolute;\n";
if (!isset($_REQUEST['slideshow'])) {
	echo "    width              : " . $_SESSION['width'] . "px;\n";
	echo "    left               : 210px;";
} else {
	echo "    width              : " . ($_SESSION['width'] + 200) . "px;";	
}
?>    
    height             : auto;
    overflow           : auto; 
    margin             : 15px; 
    background-color   : #FFF; 
    padding            : 15px; 
    text-align         : center;
    z-index            : 11;    
}
#backwards {
    position           : absolute;
    left               : 15px;    
    top                : 15px;        
}
#forwards {
    position           : absolute;
    right              : 15px;    
    top                : 15px;        
}
#slideshow {
    position           : absolute;
    left               : 15px;    
    bottom             : 15px;
    font-size          : 0.60em;
}
.thumbnail {
    margin             : 15px;
    border             : 0;
    padding            : 0;
<?
echo "    width              : " . $thumbwidth . "px;\n";
?>
    height             : auto;
    float              : left;
    display            : inline;
}
.topleft {
    position           : absolute;
    font-size          : 0;  
    left               : 0;    
    top                : 0; 
}
.topright {
    position           : absolute;
    font-size          : 0;     
    right              : 0;    
    top                : 0;     
}
.bottomleft {
    position           : absolute;
    font-size          : 0;  
    left               : 0;    
    bottom             : 0;       
}
.bottomright {
    position           : absolute;
    font-size          : 0;  
    right              : 0;    
    bottom             : 0;      
}
a:link,a:visited {
    color              : #666;
    text-decoration    : none;
}
a:hover {
    text-decoration    : underline;
}
</style>
<?

// Determine if the slideshow is active
if ($slideshow && isset($_REQUEST['slideshow']) && isset($_SESSION['images'])) {
	echo "</head><body onload=\"setTimeout('nextslide();',$slideshowdelay);window.status='Slideshow active - click photo to stop';\" >\n";  
	echo "<script type=\"text/javascript\">\n";
	echo "/*<![CDATA[*/\n";
	echo "var stop = false;\n";
	echo "function nextslide() {\n";
	echo "if (!stop)\n";
	$index=array_search($_REQUEST['photo'], $_SESSION['images']);
	if (key_exists($index + 1, $_SESSION['images'])) {
		echo "	location.href='$scriptname?page=$page&slideshow=1&photo=" . rawurlencode($_SESSION['images'][$index + 1]) . "';\n";
	} else {
		echo "	location.href='$scriptname?page=$page&slideshow=1&photo=" . rawurlencode($_SESSION['images'][0]) . "';\n";                
	}
	echo "}\n";
	echo " /*//]]>*/\n";
	echo "</script>\n";
} else {
	echo "</head><body>\n";
}

// Build the menu - enable menu cache to speed things up!!
$subalbums = false;
if(!isset($_SESSION['menulite']) || !$menu_cache) {
	$_SESSION['menulite'] = array();
	$home = false;
	$homedir = getcwd();
	if ($dir = opendir($homedir)) {
		while ($dirname = readdir($dir)) {
			if (substr($dirname,0,1) != '.' && is_dir($dirname) && $dirname != 'thumbs') {
				$_SESSION['menulite'][] = array(str_replace('.', '', $dirname), $dirname);
				photoalbums($homedir . '/' . $dirname . '/');
			} else if (substr($dirname,0,1) != '.' && !is_dir($dirname) && $dirname != $scriptname) {
				$extension = strtolower(substr($dirname, strrpos($dirname,'.') + 1, strlen($dirname)));
				if ($extension == 'jpg' || $extension == 'jpeg' || $extension == 'png' || $extension == 'gif')
					$home = true;
			}
		}
	}
	if ($home && count($_SESSION['menulite']) > 0) {
		array_unshift($_SESSION['menulite'], array(basename(dirname(__FILE__)), './'));
	}
}

// Sort the menu (only works when there are no sub-albums)
if (!$subalbums)
	array_multisort($_SESSION['menulite'], SORT_ASC);

// Print the menu
if (!isset($_REQUEST['slideshow'])) {
	echo "<div id=\"leftmenu\">\n";
	echo "<div class=\"topleft\">" .  topleftsprite() . "</div>\n";
	echo "<div class=\"topright\">" .  toprightsprite() . "</div>\n";
	$div1="<div style=\"padding-left : 15px;display : inline;\">";
	$div2="</div>";
	foreach($_SESSION['menulite'] as $key => $url) {
		$url[0]=trim($url[0],'.');
		if ($_SESSION['album'] == $key)
			echo "$div1<a href=\"$scriptname?album=$key\" style=\"text-decoration : underline;\">". htmlentities($url[0]) . "</a>$div2\n";
		else
			echo "$div1<a href=\"$scriptname?album=$key\">" . htmlentities($url[0]) . "</a>$div2\n";
		if (key_exists($key + 1, $_SESSION['menulite'])) {
			$nextmenuitem = $_SESSION['menulite'][$key + 1];
			if (substr($nextmenuitem[0],0,1)=='.') {
				echo "<br />\n";
				$padding_left = 15 + 15 * (substr_count($nextmenuitem[0], '.', 0, strpos($nextmenuitem[0], trim($nextmenuitem[0], '.'))) -1) . 'px';
				$div1 = "<div style=\"padding-left : $padding_left;display : inline;\">" . subcategorysprite();
				$div2 = "</div>";
			} else {
				echo "<div style=\"height : 10px;width : 100%;\">&nbsp;</div>";
				$div1 = "<div style=\"padding-left : 15px;display : inline;\">";
				$div2 = "</div>";
			}
		}
	}
	echo "<div style=\"height : 20px;width : 100%;\">&nbsp;</div><div style=\"padding-left : 15px;display : inline;\"><a href=\"$scriptname?help=1\">Help</a></div>\n";
	echo "<div style=\"height : 2px;width : 100%;\">&nbsp;</div><div style=\"padding-left : 15px;display : inline;\"><a href=\"$scriptname?exit=1\">Exit</a></div>\n";
	echo "<div style=\"height : 10px;width : 100%;\">&nbsp;</div><div style=\"font-size : 9px;text-align : center;padding-bottom : 5px;\"><a href=\"http://www.mywebmymail.com/?q=content/easyphpalbum-lite\">EasyPhpAlbum Lite</a></div>\n";
	echo "<div class=\"bottomleft\">" .  bottomleftsprite() . "</div>\n";
	echo "<div class=\"bottomright\">" .  bottomrightsprite() . "</div>\n";
	echo "</div>\n";
}

// Determine which album to show
if (count($_SESSION['menulite']) == 0) {
	$album = './';
} else {
	if (isset($_SESSION['album'])) {
		if (key_exists($_SESSION['album'], $_SESSION['menulite'])) {
			$albumurl = $_SESSION['menulite'][$_SESSION['album']];
			$album = $albumurl[1];
		}
	} else {
		$albumurl = $_SESSION['menulite'][0];
		$album = $albumurl[1];  
	}
}

// Read all image files when a new album is being viewed and store the images in the image cache
if (!isset($_SESSION['images'])) {
	$_SESSION['images'] = array();
	$newthumbs = array();
	if ($dir = opendir($album)) {
		while ($filename = readdir($dir)) {
			if (substr($dirname, 0, 1) != '.' && !is_dir($filename)) {
				$extension = strtolower(substr($filename, strrpos($filename,'.') + 1, strlen($filename)));
				if ($extension == 'jpg' || $extension == 'jpeg' || $extension == 'png' || $extension == 'gif') {
					$_SESSION['images'][] = $filename;
				}
			}
		}
	}	
}

// Main content
echo "<div id=\"content\">\n";
echo "<div class=\"topleft\">" .  topleftsprite() . "</div>\n";
echo "<div class=\"topright\">" .  toprightsprite() . "</div>\n";

// Display the thumbnails or the photo
$column = 0;
$thumb = new easyphpthumbnail;
$tablesize = $_SESSION['columns'] * $_SESSION['rows'];
if (isset($_REQUEST['photo'])) {$photo = basename($_REQUEST['photo']);} else {$photo = '';}
if (isset($_REQUEST['help'])) {
	// Display the help page
	echo "<strong>EasyPhpAlbum Lite Help</strong><p>Use the menu on the left to browse through the albums. In the top corners you will find the following icons:</p>\n";
	echo rowminsprite() . columnminsprite() . "<br />" . rowplussprite() . columnplussprite();
	echo "<p>Use these icons to add or remove rows and columns from the thumbnail grid to match your personal preference.</p>";
	echo "<p>Click a thumbnail to view the photo in a larger size, and use the following icons to browse backward and forward:</p>";
	echo backsprite() . " " . forwardsprite();
	echo "<p>Return to the thumbnail grid by clicking the photo.</p>";
	echo "<p>When you view a photo you will find the following icon on the left bottom corner which will start the slideshow:</p>". slideshowsprite();
	echo "<p><strong><em>Enjoy!</em></strong></p>";
	echo "<div id=\"slideshow\">Version 2.3.3</div>";
} else if ($photo == '') {
	// Display the amount of pages and the thumbnails
	if (count($_SESSION['images']) <= $page * $tablesize) {
		$page = ceil(count($_SESSION['images']) / $tablesize);
	}
	if (count($_SESSION['images']) > 0 && count($_SESSION['images']) >= ($page - 1) * $tablesize) {
		echo "<div style=\"padding-bottom : 15px;padding-left : 75px;padding-right : 75px;\">&nbsp;";
		if ($tablesize < count($_SESSION['images']) && $photo == '') {
			echo "Page: ";
			$totalpages = ceil(count($_SESSION['images']) / $tablesize);
			$mod = ceil($totalpages / 8);
			for ($i = 1; $i <= $totalpages; $i++) {
				// Don't print all pages if we have many ...
				if (fmod($i, $mod) == 0 || $i == 1 || $i == $totalpages || ($i >= $page -2 && $i <= $page +2)) {
					if ($page == $i) {
						echo " <a href=\"$scriptname?page=$i\" style=\"text-decoration : underline;\">$i</a>";
					} else {
						echo " <a href=\"$scriptname?page=$i\">$i</a>";
					} 
					if ($i != $totalpages)
						echo " - ";
				} 
			}
		}
		echo "</div>\n";
		if (count($_SESSION['images']) < $_SESSION['columns']) {
			$paddingleft = floor(($_SESSION['width'] - ($thumbwidth + 30) * count($_SESSION['images'])) / 2) . 'px';
		} else {
			$paddingleft = floor(($_SESSION['width'] - ($thumbwidth + 30) * $_SESSION['columns']) / 2) . 'px';
		}
        echo "<div style=\"padding-left : $paddingleft;padding-right : $paddingleft;height: auto;overflow: auto;\">\n";
		foreach($_SESSION['images'] as $key => $image) {
			if ($key >= ($tablesize * ($page - 1)) && $key < ($tablesize * $page)) {
				if (file_exists($album  .  '/thumbs/' . substr($image, 0, strrpos($image,'.') + 1)  . 'jpg')) {
					echo "<div class=\"thumbnail\"><a href=\"$scriptname?page=$page&amp;photo="  .  rawurlencode($image)  .  "\"><img src=\""  .  str_replace("%2F", "/", rawurlencode($album))  .  '/thumbs/' . rawurlencode(substr($image, 0, strrpos($image,'.') + 1))  . 'jpg' .  "\" style=\"border : 0px;\" alt=\"" . htmlentities($image) . "\" title=\"Click to enlarge\" /></a></div>\n";
				} else {
					// Try to create a thumbnail first
					$thumb -> Thumblocation = $album  .  '/thumbs/';
					$thumb -> Thumbsize = $thumbwidth;
					if (!$roundcorners)
						$thumb -> Clipcorner =  array(0, 15, 0, 1, 1, 1, 1);
					$thumb -> Createthumb($album  .  "/$image");	
					// Verify if the thumbnail creation worked and display the thumb
					if (file_exists($album  .  '/thumbs/' . substr($image, 0, strrpos($image,'.') + 1)  . 'jpg')) {
						echo "<div class=\"thumbnail\"><a href=\"$scriptname?page=$page&amp;photo="  .  rawurlencode($image)  .  "\"><img src=\""  .  str_replace("%2F", "/", rawurlencode($album))  .  '/thumbs/' . rawurlencode(substr($image, 0, strrpos($image,'.') + 1))  . 'jpg' .  "\" style=\"border : 0px;\" alt=\"" . htmlentities($image) . "\" title=\"Click to enlarge\" /></a></div>\n";
					} else {
						$size = getimagesize($album  .  "/$image");	// Getimagesize is slow but required to display non-cached thumbnails correctly
						if ($size[0] > $size[1]) {
							$width = $thumbwidth . 'px';
							$height = floor($size[1]/($size[0]/$thumbwidth)) . 'px';
						} else {
							$width = floor($size[0]/($size[1]/$thumbwidth)) . 'px';
							$height = $thumbwidth . 'px';
						}
						echo "<div class=\"thumbnail\"><a href=\"$scriptname?page=$page&amp;photo="  .  rawurlencode($image)  .  "\"><img src=\""  .  str_replace("%2F", "/", rawurlencode($album))  .  "/" . rawurlencode($image) . "\" style=\"border : 0px;width : $width; height : $height;\" alt=\"" . htmlentities($image) . "\" title=\"Click to enlarge\" /></a></div>\n";
					}
				}
				$column += 1;
				if ($column == $_SESSION['columns']) {
					$column = 0;
					echo '<br />';
				}
			}
		}
        echo "</div>";
		// Individual grid view preferences
		if ($changegrid && count($_SESSION['images']) > $_SESSION['columns']) {
			echo "<div id=\"backwards\">\n";
			echo "<a onmouseover=\"this.style.cursor='pointer';\" title=\"\" onclick=\"location.href=('$scriptname?page=$page&amp;rows="  .  max(1,$_SESSION['rows']-1)  .  "');\">";
			echo rowminsprite();
			echo "</a>\n";
			echo "<a onmouseover=\"this.style.cursor='pointer';\" title=\"\" onclick=\"location.href=('$scriptname?page=$page&amp;columns="  .  max(1,$_SESSION['columns']-1)  .  "');\">";
			echo columnminsprite();
			echo "</a>\n";
			echo "</div>\n";
			echo "<div id=\"forwards\">\n";
			echo "<a onmouseover=\"this.style.cursor='pointer';\" title=\"\" onclick=\"location.href=('$scriptname?page=$page&amp;rows="  .  max(1,$_SESSION['rows']+1)  .  "');\">\n";
			echo rowplussprite();
			echo "</a>\n";
			echo "<a onmouseover=\"this.style.cursor='pointer';\" title=\"\" onclick=\"location.href=('$scriptname?page=$page&amp;columns="  .  max(1,$_SESSION['columns']+1)  .  "');\">\n";
			echo columnplussprite();
			echo "</a>\n";		
			echo "</div>";	
		}
	} else {
		echo "No<br />images<br />found!<br />\n";
	}
} else {
	// Display full sized photo
	if (in_array($photo, $_SESSION['images'])) {
		$size = getimagesize($album.'/'.$photo);	// Getimagesize is slow but required to display photos correctly within the current content width
		if (!isset($_REQUEST['slideshow']))
			$maxsize = $_SESSION['width'] - 60 - 30;
		else
			$maxsize = $_SESSION['width'] + 210 - 60 - 30;		
		$width = "width : $size[0]px";
		$height = "height : $size[1]px";
		if ($size[0] > $size[1]) {
			if ($size[0] > $maxsize) {
				$width = 'width : ' . $maxsize . 'px';
				$height = 'height : ' . floor($size[1] / ($size[0] / $maxsize)) . 'px';
			} 
		} else  if ($size[1] > $size[0]) {
			if ($size[1] > $maxsize) {
				$width = 'width : ' . floor($size[0] / ($size[1] / $maxsize)) . 'px';
				$height = 'height : ' . $maxsize . 'px';
			} 		
		}
		$index = array_search($photo, $_SESSION['images']);
		$page = ceil(($index + 1) / $tablesize);
		if ($browsing && !isset($_REQUEST['slideshow']) && key_exists($index - 1, $_SESSION['images'])) {
			echo "<div id=\"backwards\"><a onmouseover=\"this.style.cursor='pointer';\" title=\"browse backward\" onclick=\"location.href=('$scriptname?page=$page&amp;photo="  .  rawurlencode($_SESSION['images'][$index - 1])  .  "');\">\n";
			echo backsprite();
			echo "</a></div>";
                }
		echo "<div><a href=\"$scriptname?page=$page\"><img src=\""  .  str_replace("%2F", "/", rawurlencode($album))  .  '/'  .  rawurlencode($photo)  .  "\" style=\"border : 0px; $width; $height\" alt=\"" . htmlentities($photo) . "\" title=\"Click to go back\" onclick=\"stop=true;\" /></a></div>\n";
		if ($show_name)
			echo "<div style=\"height : 10px;width : 100%;\">&nbsp;</div>"  . htmlentities(substr($photo, 0, strrpos($photo, '.')));		
		if ($browsing && !isset($_REQUEST['slideshow']) && key_exists($index + 1, $_SESSION['images'])) {
			echo "<div id=\"forwards\"><a onmouseover=\"this.style.cursor='pointer';\" title=\"browse forward\" onclick=\"location.href=('$scriptname?page=$page&amp;photo="  .  rawurlencode($_SESSION['images'][$index + 1])  .  "');\">\n";
			echo forwardsprite();
			echo "</a></div>";			
                }
		if ($slideshow && !isset($_REQUEST['slideshow']) && count($_SESSION['images']) > 1) {
			echo "<div id=\"slideshow\"><a onmouseover=\"this.style.cursor='pointer';\" title=\"Start Slideshow - click image to stop slideshow\" onclick=\"location.href=('$scriptname?page=$page&amp;slideshow=1&amp;photo="  .  rawurlencode($photo)  .  "');\">\n";
			echo slideshowsprite();
			echo "</a></div>";		
		}
	} else {
		echo "No<br />image<br />found!<br />\n";
	}
}

// End of page
echo "<div class=\"bottomleft\">" .  bottomleftsprite() . "</div>\n";
echo "<div class=\"bottomright\">" .  bottomrightsprite() . "</div>\n";
echo "</div>\n";
echo "</body></html>\n";

// Functions

function photoalbums($path) {

	global $homedir, $subalbums;
	if ($dir = opendir($path)) {
		while ($dirname = readdir($dir)) {
			if (substr($dirname,0,1) != '.' && is_dir($path . $dirname) && $dirname != 'thumbs') {
				$_SESSION['menulite'][] = array(str_repeat('.', substr_count($path . $dirname, '/', strlen($homedir))-1) . str_replace('.', '', $dirname), substr($path, strlen($homedir) + 1) . $dirname);
				photoalbums($path . $dirname . '/');
				$subalbums = true;
			}
		}
	}  

}

function get_rfc2397() {

	if (isset($_SERVER['HTTP_USER_AGENT'])) {
		$agent = strtolower($_SERVER['HTTP_USER_AGENT']);
		$pattern = '#(?<browser>msie|opera)[/ ]+(?<version>[0-9]+(?:\.[0-9]+)?)#';
		if (!preg_match_all($pattern, $agent, $matches))
			return true;
		$i = count($matches['browser'])-1;
		if ($matches['browser'][$i] == 'msie' && $matches['version'][$i] < 8) {
			return false;
		} else if ($matches['browser'][$i] == 'opera' && $matches['version'][$i] < 7.2) {
			return false;
		} else {
			return true;
		}
	} else {
		return true;
	}
	
}

// Sprites

function backsprite() {

if (!$_SESSION['RFC2397']) return '<';
return '<img src="data:image/gif;base64,R0lGODdhEgANAIAAAGRmZPz+/CwAAAAAEgANAAACJowPqQHs95BrTcKJTb00b451l9QlI1RmZ1p9
aGiBaUyqmmxrilkWADs=" alt="B" title="Browse backward" style="border :0px;width :18px;height :13px;" />';

}

function forwardsprite() {

if (!$_SESSION['RFC2397']) return '>';
return '<img src="data:image/gif;base64,R0lGODdhEgANAIAAAGRmZPz+/CwAAAAAEgANAAACJkSMoBrteKKTL8JJrcYUXm5oHyhmoGdO6Kg2
K9eVWOjKVestDFYAADs=" alt="F" title="Browse forward" style="border :0px;width :18px;height :13px;" />';

}

function slideshowsprite() {

if (!$_SESSION['RFC2397']) return 'S';
return '<img src="data:image/gif;base64,R0lGODdhEwARAIAAAGRmZPz+/CwAAAAAEwARAAACMoSPmRHA3p5ssE5LlVas+98Z4OiJJGmaY+pg
x5WVECXPqhxiZ9WeZbYJumARWnF4FAYLADs=" alt="C" title="Start Slideshow - click image to stop slideshow" style="border :0px;width :19px;height :17px;padding-right : 5px;" />';

}

function subcategorysprite() {

if (!$_SESSION['RFC2397']) return '- ';
return '<img src="data:image/gif;base64,R0lGODdhCgAIAIAAAJyanPz+/CwAAAAACgAIAAACD4yPqQFrfeBDQNZ7V3WwAAA7" alt="C" title="Subcategory" style="border :0px;width :10px;height :8px;padding-right : 5px;" />';

}

function rowminsprite() {

if (!$_SESSION['RFC2397']) return 'R-';
return '<img src="data:image/gif;base64,R0lGODdhFQAVAIAAAGRmZPz+/CwAAAAAFQAVAAACRISPqRDtD58JiSJ7LHWMtc5p3jaCnxiW2zlV
7jVFMtTCdtamOmuSO9kLroCYGs42S35Gykis6WRyLlGo7GmdZmmLrqIAADs=" alt="-" title="Show one row with thumbnails less" style="border :0px;width :21px;height :21px;" />';

}

function rowplussprite() {

if (!$_SESSION['RFC2397']) return 'R+';
return '<img src="data:image/gif;base64,R0lGODdhFQAVAIAAAGRmZPz+/CwAAAAAFQAVAAACR4SPqRDtD58JiSJ7LHWMtc5p3jaCnxiW2zlV
7jVFMtTCdtamOmuSO9kLroCYGs42S35GESbNKUnGnpkmNDSbNqVX5XIBThQAADs=" alt="-" title="Show one row with thumbnails more" style="border :0px;width :21px;height :21px;padding-right : 2px;" />';

}

function columnminsprite() {

if (!$_SESSION['RFC2397']) return 'C-';
return '<img src="data:image/gif;base64,R0lGODdhFQAVAIAAAGRmZPz+/CwAAAAAFQAVAAACRYSPqRDtD58JiaJoqWOsdTh93IaFpFhyVxVN
2LuphzW3o6fhdq6hlYlD7X6XHQwWWhVBtx5peHoyec2PRJasTY+vhXdRAAA7" alt="-" title="Show one column with thumbnails less" style="border :0px;width :21px;height :21px;padding-left : 2px;" />';

}

function columnplussprite() {

if (!$_SESSION['RFC2397']) return 'C+';
return '<img src="data:image/gif;base64,R0lGODdhFQAVAIAAAGRmZPz+/CwAAAAAFQAVAAACRoSPqRDtD58JiaJoqWOsdTh93IaFpFhyVxVN
2LuphzV7sWajtjfm59rT6HCZCovogr1CwBooCE0hp63oUCJjOrFK2OK7KAAAOw==" alt="-" title="Show one column with thumbnails more" style="border :0px;width :21px;height :21px;" />';

}

function topleftsprite() {

if (!$_SESSION['RFC2397']) return '';
return '<img src="data:image/gif;base64,R0lGODdhDgAOAOMAAMze7Ozy/Nzq9PT6/Nzm9NTi9Pz6/Mzi7Oz2/OTu9Pz+/AAAAAAAAAAAAAAA
AAAAACwAAAAADgAOAAAELxDISUkw6hSwN0lKGFKSgIljdwwoSrGtqAFB7AKgLQKE7uY+BSAoAgZr
RMUpyYwAADs=" alt="" title="" style="border :0px;width :13px;height :13px;" />';

}

function toprightsprite() {

if (!$_SESSION['RFC2397']) return '';
return '<img src="data:image/gif;base64,R0lGODdhDgAOAOMAAMze7Ozy/Nzq9PT6/Nzm9NTi9Pz6/Mzi7Oz2/OTu9Pz+/AAAAAAAAAAAAAAA
AAAAACwAAAAADgAOAAAELVCZQIC9WGkdSgFfuG2GgFnjOBwhkKrX8Y4dOI+me2/VvgU6nyLoSwg5
x+QmAgA7" alt="" title="" style="border :0px;width :14px;height :14px;" />';

}

function bottomleftsprite() {

if (!$_SESSION['RFC2397']) return '';
return '<img src="data:image/gif;base64,R0lGODdhDgAOAOMAAMze7Ozy/Nzq9PT6/Nzm9NTi9Pz6/Mzi7Oz2/OTu9Pz+/AAAAAAAAAAAAAAA
AAAAACwAAAAADgAOAAAELVDJSau94dqkK+gUkIEKcJBKAXAg4I4aoAJD586wd7uJYc0yF4E1MQF3
iYAvAgA7" alt="" title="" style="border :0px;width :14px;height :14px;" />';

}

function bottomrightsprite() {

if (!$_SESSION['RFC2397']) return '';
return '<img src="data:image/gif;base64,R0lGODdhDgAOAOMAAMze7Ozy/Nzq9PT6/Nzm9NTi9PT2/Pz6/Mzi7Oz2/OTu9Pz+/AAAAAAAAAAA
AAAAACwAAAAADgAOAAAELHDJSau151qjK+lUAUoBMB6ICSqA2JWAehlxIVdlGl9s6+O2mFBlIARt
yFYEADs=" alt="" title="" style="border :0px;width :14px;height :14px;" />';

}

?>
